From ed385b2562c53ab76cc5ba282bfdaccd7e7a878b Mon Sep 17 00:00:00 2001
From: Francois-Rene Rideau <tunes@google.com>
Date: Fri, 14 Dec 2012 22:42:25 -0500
Subject: [PATCH] 2.26.23: have force take precedence over force-not, again. Or
 else force-not :all won't be as useful.

---
 asdf.asd         | 2 +-
 asdf.lisp        | 7 ++++---
 doc/asdf.texinfo | 2 +-
 3 files changed, 6 insertions(+), 5 deletions(-)

diff --git a/asdf.asd b/asdf.asd
index 4a1406d7..84111812 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.26.22" ;; to be automatically updated by bin/bump-revision
+  :version "2.26.23" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")))
diff --git a/doc/asdf.texinfo b/doc/asdf.texinfo
index 9f561e89..581a628d 100644
--- a/doc/asdf.texinfo
+++ b/doc/asdf.texinfo
@@ -1475,7 +1475,7 @@ is forced not to be recompiled even if modified since last compilation,
 but other systems are not affected.
 If @var{force-not} is a list, then it specifies a list of systems that
 are forced not to be recompiled even if modified since last compilation.
-As of ASDF 2.26.22, @var{force-not} takes precedences over @var{force};
+@var{force} takes precedences over @var{force-not};
 both of them apply to systems that are dependencies and were already compiled.
 
 To see what @code{operate} would do, you can use:
diff --git a/asdf.lisp b/asdf.lisp
index 8efed19e..d6f466ed 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
 ;;; This is ASDF 2.26.22: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -118,7 +118,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.26.22")
+         (asdf-version "2.26.23")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -2224,7 +2224,8 @@ PREVIOUS-TIME when not null is the time at which the PREVIOUS system was loaded.
 (defun* visit-action (o c plan recurse fun)
   (when (and o c
              (aif (component-if-feature c) (featurep it) t)
-             (not (action-override-p o c 'operation-forced-not)))
+             (or (action-override-p o c 'operation-forced)
+                 (not (action-override-p o c 'operation-forced-not))))
     (visit-dependencies o c recurse)
     (multiple-value-bind (stamp done-p)
         (compute-action-stamp o c :plan plan #|:base-stamp (visit-dependencies o c recurse)|#)
@@ -1,5 +1,5 @@
 ;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.26.22: Another System Definition Facility.
+;;; This is ASDF 2.26.23: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
-- 
GitLab